Welcome to coilpy's documentation!
==================================
This is Caoxiang Zhu's personal Python package for plotting and data processing.

You can check the Python API documentation.
:doc:`api/coilpy`

Or check the examples.
:doc:`example`

.. toctree::
   :maxdepth: 4
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
